pub struct ContextManager { /* private fields */ }Expand description
The central actor responsible for managing the lifecycle of all contexts.
As an actor, it maintains its own state and processes incoming messages sequentially from a mailbox.
Implementations
Sourceimpl ContextManager
impl ContextManager
pub fn get_module( &self, application_id: ApplicationId, ) -> impl ActorFuture<Self, Output = Result<Module>> + 'static
Sourceimpl ContextManager
Creates a new ContextManager.
impl ContextManager
Creates a new ContextManager.
Arguments
datastore- The persistent storage backend.node_client- Client for interacting with the underlying Calimero node.context_client- The context client facade.external_config- Configuration for interacting with external blockchain contracts (e.g., NEAR).prometheus_registry- A mutable reference to a Prometheus registry for registering metrics.
pub fn new( datastore: Store, node_client: NodeClient, context_client: ContextClient, external_config: ExternalClientConfig, prometheus_registry: Option<&mut Registry>, ) -> Self